@@ -1,7 +1,7 @@
 """
     This module implements the Stockfish class.
 
-    :copyright: (c) 2016-2020 by Ilya Zhelyabuzhsky.
+    :copyright: (c) 2016-2021 by Ilya Zhelyabuzhsky.
     :license: MIT, see LICENSE for more details.
 """
 
@@ -34,6 +34,8 @@ class Stockfish:
             path, universal_newlines=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE
         )
 
+        self._stockfish_major_version: int = int(self._read_line().split(" ")[1])
+
         self._put("uci")
 
         self.depth = str(depth)
@@ -113,7 +115,7 @@ class Stockfish:
         self._put(f"position startpos moves {self._convert_move_list_to_str(moves)}")
 
     def get_board_visual(self) -> str:
-        """ Get a visual representation of the current board position 
+        """Get a visual representation of the current board position
             Note: "d" is a stockfish only command
 
         Args:
@@ -132,7 +134,7 @@ class Stockfish:
         return board_rep
 
     def get_fen_position(self) -> str:
-        """ Get current board position in Forsyth–Edwards notation (FEN).
+        """Get current board position in Forsyth–Edwards notation (FEN).
 
         Args:
 
@@ -235,13 +237,14 @@ class Stockfish:
             A dictionary of the current advantage with "type" as "cp" (centipawns) or "mate" (checkmate in)
         """
 
-        fen = self.get_fen_position()
-        if "w" in fen:  # w can only be in FEN if it is whites move
+        evaluation = dict()
+        fen_position = self.get_fen_position()
+        if "w" in fen_position:  # w can only be in FEN if it is whites move
             compare = 1
         else:  # stockfish shows advantage relative to current player, convention is to do white positive
             compare = -1
-        self._put("position " + fen + "\n go")
-        last_text: str = ""
+        self._put(f"position {fen_position}")
+        self._go()
         while True:
             text = self._read_line()
             splitted_text = text.split(" ")
@@ -254,7 +257,6 @@ class Stockfish:
                         }
             elif splitted_text[0] == "bestmove":
                 return evaluation
-            last_text = text
 
     def set_depth(self, depth_value: int = 2) -> None:
         """Sets current depth of stockfish engine.
@@ -267,5 +269,17 @@ class Stockfish:
         """
         self.depth = str(depth_value)
 
+    def get_stockfish_major_version(self):
+        """Get Stockfish engine major version.
+
+        Args:
+            None
+
+        Returns:
+            Current stockfish major version
+        """
+
+        return self._stockfish_major_version
+
     def __del__(self) -> None:
         self.stockfish.kill()
